'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var react = require('react');
var lunr = require('lunr');
var warning = _interopDefault(require('tiny-warning'));
var invariant = _interopDefault(require('tiny-invariant'));

var useLunr = function useLunr(query, rawIndex, rawStore) {
  var index = react.useMemo(function () {
    if (rawIndex === undefined || rawIndex === null) {
       warning(rawIndex !== undefined && rawIndex !== null, 'No index was provided. Results will always be empty.') ;
      return;
    }

    if (rawIndex instanceof lunr.Index) return rawIndex;
    if (typeof rawIndex === 'string') return lunr.Index.load(JSON.parse(rawIndex));
    if (typeof rawIndex === 'object') return lunr.Index.load(rawIndex);
      invariant(false, 'Invalid index provided. Please provide an instance of Lunr.Index or exported JSON or string index.')  ;
  }, [rawIndex]);
  var store = react.useMemo(function () {
    if (typeof rawStore === 'string') return JSON.parse(rawStore);
    return rawStore;
  }, [rawStore]);
  return react.useMemo(function () {
    if (!query || !index) return [];
    var results = typeof query === 'string' ? index.search(query) : index.query(query);
    if (store) return results.map(function (_ref) {
      var ref = _ref.ref;
      return store[ref];
    });
    return results;
  }, [query, index, store]);
};

exports.useLunr = useLunr;
//# sourceMappingURL=react-lunr.cjs.development.js.map
